%{
/* C++ string header, for string ops below */
#include <string>
#include <QString>
/* Implementation of yyFlexScanner */
#include "vhdl_scanner.h"
#include <QDebug>
/* define to keep from re-typing the same code over and over */
#define STOKEN( x ) ( new QString( x ) )

/* define yyterminate as this instead of NULL */
//#define yyterminate() return( token::END )

/* msvc2010 requires that we exclude this header file. */
#define YY_NO_UNISTD_H

/* handle locations */
int yycolumn = 1;

#define YY_USER_ACTION yycolumn += yyleng;

%}
%option debug
%option nodefault
%option yyclass="vhdl_Scanner"
%option case-insensitive yylineno
%option noyywrap
%option c++


%%

  /*-----------------------------------------------------------*/
  /*Separators*/
[ \t]+ { } //skip new lines, blanc spaces and tabulations
  /*-----------------------------------------------------------*/
\n {yycolumn=1;}

  /*comment*/
--.* {
    //this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::comment,yylineno, yycolumn-yyleng));
}
  /*-----------------------------------------------------------*/

        /*Reserved words*/

abs |
access |
after |
alias |
all |
and |
array |
assert |
attribute |
begin |
body |
buffer |
bus |
disconnect |
downto |
else |
elsif |
exit |
file |
function |
generate |   /* don't parse generate as block! just look for "if" or "for" */
group |
guarded |
impure |
in |
inertial |
inout |
is |
label |
linkage |
literal |
mod |
nand |
new |
next |
nor |
not |
null |
of |
on |
open |
or |
others |
out |
postponed |
pure |
range |
register |
reject |
rem |
report |
return |
rol |
ror |
select |
severity |
shared |
sla |
sll |
sra |
srl |
then |
to |
transport |
unaffected |
until |
wait |
when |
while |
with |
xnor |
xor |
(true|false) {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::keyword,yylineno, yycolumn-yyleng));}

port {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::port,yylineno, yycolumn-yyleng));}

generic {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::generic,yylineno, yycolumn-yyleng));}

map {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::map,yylineno, yycolumn-yyleng));}

architecture |
block |
case |
configuration |
component |
for |
if |
loop |
package |
procedure |
process |
protected |
record {
        this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::block,yylineno, yycolumn-yyleng));
     }

entity {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::entity,yylineno, yycolumn-yyleng));}


units {
        this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::units,yylineno, yycolumn-yyleng));
    }

constant |
library |
signal |
subtype |
type |
use |
variable {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::clause,yylineno, yycolumn-yyleng));}



end {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::endKw,yylineno, yycolumn-yyleng));}


  /*-----------------------------------------------------------*/

  /*identifier (may be a reserved word)*/
[a-z][a-z0-9\_\.]+[a-z0-9]+ |
[a-z]+ |
\\.*\\ {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::identifier,yylineno, yycolumn-yyleng));}

  /*-----------------------------------------------------------*/

  /*abstract literal (integer or floating point type)*/
    /*Numerical literals*/
(\+|\-)?([0-9\_]+)|(\+|\-)?([0-9\_]+E[0-9\_]+)|((2|3|4|5|6|7|8|9|10|11|12|13|14|15|16)\#[0-9\_]\#) {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::literal,yylineno, yycolumn-yyleng));}

(\+|\-)?[0-9\_]+\.[0-9\_]+|[0-9\_]+\.[0-9\_]+E[0-9\_]+ {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::literal,yylineno, yycolumn-yyleng));}

\'(0|1)\' {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::literal,yylineno, yycolumn-yyleng));}

\'.\' {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::literal,yylineno, yycolumn-yyleng));}


(\+|\-)?([0-9\_]+)(fs|ps|ns|us|ms|sec|min|hr) {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::literal,yylineno, yycolumn-yyleng));}

    /*Bit string literals*/
\"[0-1\_]+\" {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::literal,yylineno, yycolumn-yyleng));}

    /*String literals*/
\".*\" {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::literal,yylineno, yycolumn-yyleng));}

x\"[0-9A-F\_]+\" {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::literal,yylineno, yycolumn-yyleng));}

o\"[0-7\_]+\" {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::literal,yylineno, yycolumn-yyleng));}

    /*The NULL literal*/

\[NULL\] {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::literal,yylineno, yycolumn-yyleng));}

  /*-----------------------------------------------------------*/

  /*character literal (a graphical character surrounded by ‘, e.g.: ‘H’)*/
  /*-----------------------------------------------------------*/

  /*string literal (a sequence of graphical characters surrounded by ”, e.g.: ”HAR-DI”)*/
  /*-----------------------------------------------------------*/

  /* bit string literal (a sequence of extended digits * surrounded by ”, e.g.: ”011”)*/
  /*-----------------------------------------------------------*/

  /* delimiter*/
\. | \| | \[ | \] |
\:= | \>\= |
\<\= |
\/\= |
\= |
\> |
\< |
\& |
\‘ |
\' |
\=\> |
\<\> |
\, |
\* |
\+ |
\- |
\/ |
\*\* {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::separator,yylineno, yycolumn-yyleng)); }


\: {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::colon,yylineno, yycolumn-yyleng)); }


\( {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::leftParen,yylineno, yycolumn-yyleng));}

\) {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::rightParen,yylineno, yycolumn-yyleng));}


\; {this->appendNode(new VHDL_Tools::VHDL_AST_Node(YYText(),VHDL_Tools::semicolon,yylineno, yycolumn-yyleng)); }

. printf("bad input character '%s' at line %d column %d\n ", yytext, yylineno,yycolumn-yyleng);

%%







